==> sharpshooter-0.0.10.tar.gz: sharpshooter-0.0.10/sharpshooter/__main__.py <==
"""
    ¥ tree (sharpshooter) CLI entry point.
    ====================================

"""

import argparse
import os
import sys

from sharpshooter import tree


def parse_args():
    parser = argparse.ArgumentParser(
        add_help=False,
        prog="sharpshooter",
        usage="%(prog)s [options]",
        description="Generate filesystems with Python 3",
    )

    # parser.add_argument('-h', '--help', action='store_true')
    parser.add_argument("-v", "--version", action="store_true")
    # parser.add_argument('-d', '--debug', action='store_true')
    # parser.add_argument('-q', '--quiet', action='store_true')
    # parser.add_argument('-c', '--config', action='store')
    # parser.add_argument('-i', '--input', action='store_true') # create trees from terminal input
    parser.add_argument("-f", "--file", nargs="?", type=argparse.FileType("r"))
    parser.add_argument("-t", "--test", nargs="?", type=argparse.FileType("r"))
    parser.add_argument(
        "-c",
        "--create",
        help="Create a helloworld.tree file",
        type=str,
        nargs="?",
        default="helloworld",
    )

    args = parser.parse_args()
    return args


def do_things(arguments):
    if arguments.version is True:
        from sharpshooter import __version__

        print(__version__)
        return __version__
    if arguments.test is not None:
        filecontent = ""
        with open(arguments.test.name, "r") as f:
            filecontent = f.read()
            f.close()
        tree(filecontent, test=True)
        return
    if arguments.file is not None:
        filecontent = ""
        with open(arguments.file.name, "r") as f:
            filecontent = f.read()
            f.close()
        tree(filecontent)
        return
    if arguments.create is not None:
        name = "helloworld"
        if arguments.create is not None:
            name = arguments.create
        filename = f"{name}.tree"
        with open(filename, "w") as f:
            f.write(
                """
+hello
    world.txt
"""
            )

        print("done")
        return


def run():
    """[Entry point required by setup.py console_scripts.]"""
    args = parse_args()
    do_things(args)


if __name__ == "__main__":
    run()

==> sharpshooter-0.0.11.tar.gz: sharpshooter-0.0.11/sharpshooter/__main__.py <==
"""
    ¥ tree (sharpshooter) CLI entry point.
    ====================================

"""

import argparse
import os
import sys

from sharpshooter import tree


def parse_args():
    parser = argparse.ArgumentParser(
        add_help=False,
        prog="sharpshooter",
        usage="%(prog)s [options]",
        description="Generate filesystems with Python 3",
    )

    # parser.add_argument('-h', '--help', action='store_true')
    parser.add_argument("-v", "--version", action="store_true")
    # parser.add_argument('-d', '--debug', action='store_true')
    # parser.add_argument('-q', '--quiet', action='store_true')
    # parser.add_argument('-c', '--config', action='store')
    # parser.add_argument('-i', '--input', action='store_true') # create trees from terminal input
    parser.add_argument(
        "-f",
        "--file",
        help="Create a directory structure from a .tree file",
        nargs="?",
        type=argparse.FileType("r")
    )
    parser.add_argument(
        "-t",
        "--test",
        help="test mode won't write to the filesystem",
        nargs="?",
        type=argparse.FileType("r")
    )
    parser.add_argument(
        "-c",
        "--create",
        help="Create a helloworld.tree file",
        type=str,
        nargs="?",
        default="helloworld",
    )
    parser.add_argument(
        "-j",
        "--jinja",
        help="Create a directory structure from a .tree file. But passes through Jinja first.",
        nargs="*",
        type=str
    )

    args = parser.parse_args()
    return args


def do_things(arguments):
    if arguments.version is True:
        from sharpshooter import __version__
        print(__version__)
        return __version__
    if arguments.test is not None:
        filecontent = ""
        with open(arguments.test.name, "r") as f:
            filecontent = f.read()
            f.close()
        tree(filecontent, test=True)
        return
    if arguments.file is not None:
        # TODO - if no file passed find one called .tree and use it anyway? at least ask for confirmation
        filecontent = ""
        with open(arguments.file.name, "r") as f:
            filecontent = f.read()
            f.close()
        tree(filecontent)
        return

    if arguments.jinja is not None:
        try:
            from jinja2 import Environment, FileSystemLoader
        except ImportError:
            raise ImportError("This option requires Jinja2 to be installed")
        filecontent = ""
        kwargs = {}
        args = arguments.jinja
        tmpfile = args.pop(0)
        # print(tmpfile, args)
        for arg in args:
            key, val = arg.split("=")
            kwargs[key] = val
        env = Environment(
            loader=FileSystemLoader(searchpath="./")
        )
        template = env.get_template(tmpfile)
        # print(kwargs)
        filecontent = template.render(**kwargs)
        tree(filecontent)
        return
    # sharpshooter -j testjinja.tree replaceme=somefolder andme=another count=20

    if arguments.create is not None:
        name = "helloworld"
        if arguments.create is not None:
            name = arguments.create
        filename = f"{name}.tree"
        with open(filename, "w") as f:
            f.write(
                """
+hello
    world.txt
"""
            )

        print("done")
        return


def run():
    """[Entry point required by setup.py console_scripts.]"""
    args = parse_args()
    do_things(args)


if __name__ == "__main__":
    run()
